unit delays;                                    { Delay routines, v23   }
interface                                       { By Jens Dyekjr Madsen}
{$s-}
const
  t2u5 = -5;                                    { (5+1)*419ns = 2.51s  }
  t5u  = -11;                                   { 12 * 419ns  = 5.03s  }
  t7u5 = -17;                                   { 18 * 419ns  = 7.54s  }
  t10u = -23;                                   { 24 * 419ns  = 10.06s }
  sdt  = t7u5;                                  { Shortdelay  = 7.5s   }

procedure shortdelay;                           { Short delay           }
inline(
  $E4/$42/      {       IN      AL,[42]         ; Read timer 2, LSB     }
  $B3/<sdt/     {       MOV     BL,sdt          ; Setup delay time      }
  $00/$C3/      {       ADD     BL,AL           ; Calculate stop time   }
  $EB/$00/      {       JMP     $+2             ; I/O delay             }
  $EB/$00/      {L1:    JMP     $+2             ; I/O delay             }
  $E4/$42/      {       IN      AL,[42]         ; Read timer 2, LSB     }
  $38/$D8/      {       CMP     AL,BL           ; Compare with stoptime }
  $79/$F8);     {       JNS     L1              ; Continue until timeout}

procedure waitdelay(t: word);                   { Delay / 50us          }

procedure timerstart;                           { Start timer           }

procedure timerstop;                            { Stop timer            }


implementation

procedure waitdelay(t: word); assembler;        { Delay / 50us          }
asm
        in      al,42h                          { Read timer 2 LSB      }
        mov     ah,al                           { Save in AH            }
        mov     cx,t                            { cx = t                }
        jmp     @2                              { I/O delay             }
@2:     sub     ah,120                          { Calculate stoptime    }
@1:     jmp     @0                              { I/O delay             }
@0:     in      al,42h                          { Read timer 2 LSB      }
        cmp     al,ah                           { Compare with stoptime }
        jns     @1                              { Continue until timeout}
        loop    @2                              { Loop t times          }
end;

procedure timerstart;                           { Start timer           }
begin
  port[$43]:=$96;                               { R/W LSB only          }
  port[$61]:=port[$61] or 1;                    { Start timer 2         }
  port[$42]:=0;                                 { Initialize timer 2    }
end;

procedure timerstop;                            { Timer stop            }
begin
  port[$61]:=port[$61] and $fe;                 { Stop timer 2          }
end;

end.
